@@ -6,9 +6,9 @@ use warnings;
 use Mo qw(build is);
 use Mo::utils qw(check_required);
 use Mo::utils::CEFACT 0.02 qw(check_cefact_unit);
-use Mo::utils::Number qw(check_number);
+use Mo::utils::Number 0.02 qw(check_number);
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 has unit => (
 	is => 'ro',
@@ -167,6 +167,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
